"use client";
import {
  PrimaryDocument,
  PrimaryElectronic,
  PrimaryFacebook,
  PrimaryInsta,
  PrimaryLinkdIn,
  PrimaryListing,
  PrimaryLogout,
  PrimaryPassword,
  PrimaryProfile,
  PrimaryProtocol,
  PrimarySale,
  PrimarySecurity,
  PrimaryTickTok,
  PrimaryTwitter,
} from "@/components/Icons";
import { DocumentTab } from "@/components/modules/SellerProfile/DocumentTab";
import { ElectronicTab } from "@/components/modules/SellerProfile/ElectronicTab";
import MyListingTab from "@/components/modules/SellerProfile/MyListingTab";
import { MyProfileTab } from "@/components/modules/SellerProfile/MyProfileTab";
import { ProtocolTab } from "@/components/modules/SellerProfile/ProtocolTab";
import { SaleTab } from "@/components/modules/SellerProfile/SaleTab";
import axios from "axios";
import Image from "next/image";
import Link from "next/link";
import React, { useEffect, useState } from "react";

const SellerProfile = () => {
  const [selectedTabIdx, setSelectedTabIdx] = useState(0);
  const [user, setUser] = useState({});
  const [userId] = useState("664761659d34b4208fafa189");

  useEffect(() => {
    axios
      .get(`${process.env.NEXT_PUBLIC_BASE_URL}/assetHolder/${userId}`)
      .then((response) => {
        setUser(response.data);
      })
      .catch((error) => {
        console.error("There was an error fetching the user!", error);
      });
  }, [userId]);

  const tabs = [
    { icon: <PrimaryProfile />, name: "My Profile", link: "/seller-profile" },
    {
      icon: <PrimaryListing />,
      name: "My Listing",
      link: "/seller-profile/my-listing",
    },
    {
      icon: <PrimaryProtocol />,
      name: "Confidentiality and Protocol",
      link: "/seller-profile/confidentiality-protocol",
    },
    {
      icon: <PrimaryElectronic />,
      name: "Electronic Consent",
      link: "/seller-profile/electronic-consent",
    },
    {
      icon: <PrimaryDocument />,
      name: "Documents Storage",
      link: "/seller-profile/documents-storage",
    },
    {
      icon: <PrimarySale />,
      name: "Sale Tracker",
      link: "/seller-profile/sale-tracker",
    },
    {
      icon: <PrimarySecurity />,
      name: "Security",
      link: "/seller-profile/security",
    },
    {
      icon: <PrimaryPassword />,
      name: "Change Password",
      link: "/seller-profile/change-password",
    },
    { icon: <PrimaryLogout />, name: "Sign Out", link: "#" },
  ];

  return (
    <div className="theme-container !py-8 flex flex-col md:flex-row gap-7">
      <div className="flex flex-col gap-7 m:min-w-[385px]">
        <div className="custom-shadow flex justify-center items-center flex-col py-6 rounded">
          <figure>
            <Image
              src={user.profileImage || "/assets/images/seller-profile.png"}
              alt="Profile"
              height={184}
              width={184}
              className="mb-5 rounded-full"
            />
          </figure>
          <h1 className="text-prussianBlue font-semibold text-3xl">
            {user.fullName || "Loading..."}
          </h1>
          <h2 className="text-2xl text-prussianBlue mb-3">Asset Holder</h2>
          <div className="flex gap-3">
            <Link href="#">
              <PrimaryFacebook className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryInsta className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryLinkdIn className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryTwitter className="h-[17px] w-[17px]" />
            </Link>
            <Link href="#">
              <PrimaryTickTok className="h-[17px] w-[17px]" />
            </Link>
          </div>
        </div>
        <div className="flex flex-col custom-shadow rounded py-5">
          <div>
            <nav className=" flex flex-col" aria-label="Tabs">
              {tabs.map((tab, i) => (
                <button
                  type="button"
                  key={tab.name}
                  className={`${
                    i === selectedTabIdx
                      ? "  bg-whiteSmoke text-prussianBlue font-medium focus:outline-none "
                      : "border-transparent"
                  } whitespace-nowrap flex gap-3 hover:bg-whiteSmoke hover:text-prussianBlue items-center py-2 px-8 cursor-pointer sm:text-xl`}
                  onClick={() => setSelectedTabIdx(i)}
                >
                  {tab.icon}
                  {tab.name}
                </button>
              ))}
            </nav>
          </div>
        </div>
      </div>
      <div className="grow">
        {selectedTabIdx === 0 && <MyProfileTab activeTab={0} />}
        {selectedTabIdx === 1 && <MyListingTab />}
        {selectedTabIdx === 2 && <ProtocolTab />}
        {selectedTabIdx === 3 && <ElectronicTab />}
        {selectedTabIdx === 4 && <DocumentTab />}
        {selectedTabIdx === 5 && <SaleTab />}
        {selectedTabIdx === 6 && <MyProfileTab activeTab={2} />}
        {selectedTabIdx === 7 && <MyProfileTab activeTab={3} />}
      </div>
    </div>
  );
};

export default SellerProfile;
